@@ -12,6 +12,21 @@ typedef struct { PyObject_HEAD } PyMethodObject;
 typedef struct { PyObject_HEAD } PyListObject;
 typedef struct { PyObject_HEAD } PyLongObject;
 typedef struct { PyObject_HEAD } PyBaseExceptionObject;
+
+/* hack for https://bugs.python.org/issue29943 */
+
+PyAPI_FUNC(int) PyPySlice_GetIndicesEx(PyObject *arg0,
+                    Signed arg1, Signed *arg2,
+                    Signed *arg3, Signed *arg4, Signed *arg5);
+#ifdef __GNUC__
+__attribute__((__unused__))
+#endif
+static int PySlice_GetIndicesEx(PyObject *arg0, Py_ssize_t arg1,
+        Py_ssize_t *arg2, Py_ssize_t *arg3, Py_ssize_t *arg4,
+        Py_ssize_t *arg5) {
+    return PyPySlice_GetIndicesEx(arg0, arg1, arg2, arg3,
+                arg4, arg5);
+}
 #define PyAnySet_Check PyPyAnySet_Check
 PyAPI_FUNC(int) PyAnySet_Check(struct _object *arg0);
 #define PyAnySet_CheckExact PyPyAnySet_CheckExact
@@ -68,16 +83,6 @@ PyAPI_FUNC(struct _object *) PyCMethod_New(struct PyMethodDef *arg0, struct _obj
 PyAPI_FUNC(struct _object *) PyCallIter_New(struct _object *arg0, struct _object *arg1);
 #define PyCallable_Check PyPyCallable_Check
 PyAPI_FUNC(int) PyCallable_Check(struct _object *arg0);
-#define PyCapsule_New PyPyCapsule_New
-PyAPI_FUNC(PyObject *) PyCapsule_New(void * arg0, char const * arg1, PyCapsule_Destructor arg2);
-#define PyCapsule_SetContext PyPyCapsule_SetContext
-PyAPI_FUNC(int) PyCapsule_SetContext(PyObject * arg0, void * arg1);
-#define PyCapsule_SetDestructor PyPyCapsule_SetDestructor
-PyAPI_FUNC(int) PyCapsule_SetDestructor(PyObject * arg0, PyCapsule_Destructor arg1);
-#define PyCapsule_SetName PyPyCapsule_SetName
-PyAPI_FUNC(int) PyCapsule_SetName(PyObject * arg0, char const * arg1);
-#define PyCapsule_SetPointer PyPyCapsule_SetPointer
-PyAPI_FUNC(int) PyCapsule_SetPointer(PyObject * arg0, void * arg1);
 #define PyClassMethod_New PyPyClassMethod_New
 PyAPI_FUNC(struct _object *) PyClassMethod_New(struct _object *arg0);
 #define PyCode_Addr2Line PyPyCode_Addr2Line
@@ -86,22 +91,12 @@ PyAPI_FUNC(int) PyCode_Addr2Line(PyCodeObject *arg0, int arg1);
 PyAPI_FUNC(int) PyCode_Check(void * arg0);
 #define PyCode_CheckExact PyPyCode_CheckExact
 PyAPI_FUNC(int) PyCode_CheckExact(void * arg0);
-#define PyCode_GetCellvars PyPyCode_GetCellvars
-PyAPI_FUNC(struct _object *) PyCode_GetCellvars(PyCodeObject *arg0);
-#define PyCode_GetCode PyPyCode_GetCode
-PyAPI_FUNC(struct _object *) PyCode_GetCode(PyCodeObject *arg0);
-#define PyCode_GetFreevars PyPyCode_GetFreevars
-PyAPI_FUNC(struct _object *) PyCode_GetFreevars(PyCodeObject *arg0);
 #define PyCode_GetNumFree PyPyCode_GetNumFree
 PyAPI_FUNC(Signed) PyCode_GetNumFree(PyCodeObject *arg0);
-#define PyCode_GetVarnames PyPyCode_GetVarnames
-PyAPI_FUNC(struct _object *) PyCode_GetVarnames(PyCodeObject *arg0);
 #define PyCode_New PyPyCode_New
 PyAPI_FUNC(PyCodeObject *) PyCode_New(int arg0, int arg1, int arg2, int arg3, int arg4, struct _object *arg5, struct _object *arg6, struct _object *arg7, struct _object *arg8, struct _object *arg9, struct _object *arg10, struct _object *arg11, struct _object *arg12, int arg13, struct _object *arg14);
 #define PyCode_NewEmpty PyPyCode_NewEmpty
 PyAPI_FUNC(PyCodeObject *) PyCode_NewEmpty(const char *arg0, const char *arg1, int arg2);
-#define PyCode_NewWithPosOnlyArgs PyPyCode_NewWithPosOnlyArgs
-PyAPI_FUNC(PyCodeObject *) PyCode_NewWithPosOnlyArgs(int arg0, int arg1, int arg2, int arg3, int arg4, int arg5, struct _object *arg6, struct _object *arg7, struct _object *arg8, struct _object *arg9, struct _object *arg10, struct _object *arg11, struct _object *arg12, struct _object *arg13, struct _object *arg14, int arg15, struct _object *arg16, struct _object *arg17);
 #define PyCodec_Decode PyPyCodec_Decode
 PyAPI_FUNC(struct _object *) PyCodec_Decode(struct _object *arg0, const char *arg1, const char *arg2);
 #define PyCodec_Decoder PyPyCodec_Decoder
@@ -128,8 +123,6 @@ PyAPI_FUNC(double) PyComplex_RealAsDouble(struct _object *arg0);
 PyAPI_FUNC(int) PyContextVar_Get(struct _object *arg0, struct _object *arg1, struct _object **arg2);
 #define PyContextVar_New PyPyContextVar_New
 PyAPI_FUNC(struct _object *) PyContextVar_New(const char *arg0, struct _object *arg1);
-#define PyContextVar_Reset PyPyContextVar_Reset
-PyAPI_FUNC(struct _object *) PyContextVar_Reset(struct _object *arg0, struct _object *arg1);
 #define PyContextVar_Set PyPyContextVar_Set
 PyAPI_FUNC(struct _object *) PyContextVar_Set(struct _object *arg0, struct _object *arg1);
 #define PyCoro_Check PyPyCoro_Check
@@ -148,8 +141,6 @@ PyAPI_FUNC(int) PyDateTime_DATE_GET_MICROSECOND(void *arg0);
 PyAPI_FUNC(int) PyDateTime_DATE_GET_MINUTE(void *arg0);
 #define PyDateTime_DATE_GET_SECOND PyPyDateTime_DATE_GET_SECOND
 PyAPI_FUNC(int) PyDateTime_DATE_GET_SECOND(void *arg0);
-#define PyDateTime_DATE_GET_TZINFO PyPyDateTime_DATE_GET_TZINFO
-PyAPI_FUNC(struct _object *) PyDateTime_DATE_GET_TZINFO(void *arg0);
 #define PyDateTime_DELTA_GET_DAYS PyPyDateTime_DELTA_GET_DAYS
 PyAPI_FUNC(int) PyDateTime_DELTA_GET_DAYS(void *arg0);
 #define PyDateTime_DELTA_GET_MICROSECONDS PyPyDateTime_DELTA_GET_MICROSECONDS
@@ -176,8 +167,6 @@ PyAPI_FUNC(int) PyDateTime_TIME_GET_MICROSECOND(void *arg0);
 PyAPI_FUNC(int) PyDateTime_TIME_GET_MINUTE(void *arg0);
 #define PyDateTime_TIME_GET_SECOND PyPyDateTime_TIME_GET_SECOND
 PyAPI_FUNC(int) PyDateTime_TIME_GET_SECOND(void *arg0);
-#define PyDateTime_TIME_GET_TZINFO PyPyDateTime_TIME_GET_TZINFO
-PyAPI_FUNC(struct _object *) PyDateTime_TIME_GET_TZINFO(void *arg0);
 #define PyDate_Check PyPyDate_Check
 PyAPI_FUNC(int) PyDate_Check(struct _object *arg0);
 #define PyDate_CheckExact PyPyDate_CheckExact
@@ -254,8 +243,6 @@ PyAPI_FUNC(int) PyErr_ExceptionMatches(struct _object *arg0);
 PyAPI_FUNC(void) PyErr_Fetch(struct _object **arg0, struct _object **arg1, struct _object **arg2);
 #define PyErr_GetExcInfo PyPyErr_GetExcInfo
 PyAPI_FUNC(void) PyErr_GetExcInfo(struct _object **arg0, struct _object **arg1, struct _object **arg2);
-#define PyErr_GetHandledException PyPyErr_GetHandledException
-PyAPI_FUNC(struct _object *) PyErr_GetHandledException(void);
 #define PyErr_GivenExceptionMatches PyPyErr_GivenExceptionMatches
 PyAPI_FUNC(int) PyErr_GivenExceptionMatches(struct _object *arg0, struct _object *arg1);
 #define PyErr_NoMemory PyPyErr_NoMemory
@@ -280,8 +267,8 @@ PyAPI_FUNC(struct _object *) PyErr_SetFromErrnoWithFilename(struct _object *arg0
 PyAPI_FUNC(struct _object *) PyErr_SetFromErrnoWithFilenameObject(struct _object *arg0, struct _object *arg1);
 #define PyErr_SetFromErrnoWithFilenameObjects PyPyErr_SetFromErrnoWithFilenameObjects
 PyAPI_FUNC(struct _object *) PyErr_SetFromErrnoWithFilenameObjects(struct _object *arg0, struct _object *arg1, struct _object *arg2);
-#define PyErr_SetHandledException PyPyErr_SetHandledException
-PyAPI_FUNC(void) PyErr_SetHandledException(struct _object *arg0);
+#define PyErr_SetInterrupt PyPyErr_SetInterrupt
+PyAPI_FUNC(void) PyErr_SetInterrupt(void);
 #define PyErr_SetNone PyPyErr_SetNone
 PyAPI_FUNC(void) PyErr_SetNone(struct _object *arg0);
 #define PyErr_SetObject PyPyErr_SetObject
@@ -306,8 +293,6 @@ PyAPI_FUNC(struct _object *) PyEval_EvalCode(struct _object *arg0, struct _objec
 PyAPI_FUNC(struct _object *) PyEval_GetBuiltins(void);
 #define PyEval_GetFrame PyPyEval_GetFrame
 PyAPI_FUNC(PyFrameObject *) PyEval_GetFrame(void);
-#define PyEval_GetFuncName PyPyEval_GetFuncName
-PyAPI_FUNC(const char *) PyEval_GetFuncName(struct _object *arg0);
 #define PyEval_GetGlobals PyPyEval_GetGlobals
 PyAPI_FUNC(struct _object *) PyEval_GetGlobals(void);
 #define PyEval_GetLocals PyPyEval_GetLocals
@@ -352,26 +337,10 @@ PyAPI_FUNC(int) PyFile_WriteString(const char *arg0, struct _object *arg1);
 PyAPI_FUNC(double) PyFloat_AS_DOUBLE(void *arg0);
 #define PyFloat_AsDouble PyPyFloat_AsDouble
 PyAPI_FUNC(double) PyFloat_AsDouble(struct _object *arg0);
-#define PyFloat_Check PyPyFloat_Check
-PyAPI_FUNC(int) PyFloat_Check(void * arg0);
-#define PyFloat_CheckExact PyPyFloat_CheckExact
-PyAPI_FUNC(int) PyFloat_CheckExact(void * arg0);
 #define PyFloat_FromDouble PyPyFloat_FromDouble
 PyAPI_FUNC(struct _object *) PyFloat_FromDouble(double arg0);
 #define PyFloat_FromString PyPyFloat_FromString
 PyAPI_FUNC(struct _object *) PyFloat_FromString(struct _object *arg0);
-#define PyFrame_GetBuiltins PyPyFrame_GetBuiltins
-PyAPI_FUNC(struct _object *) PyFrame_GetBuiltins(PyFrameObject *arg0);
-#define PyFrame_GetGenerator PyPyFrame_GetGenerator
-PyAPI_FUNC(struct _object *) PyFrame_GetGenerator(PyFrameObject *arg0);
-#define PyFrame_GetGlobals PyPyFrame_GetGlobals
-PyAPI_FUNC(struct _object *) PyFrame_GetGlobals(PyFrameObject *arg0);
-#define PyFrame_GetLasti PyPyFrame_GetLasti
-PyAPI_FUNC(int) PyFrame_GetLasti(PyFrameObject *arg0);
-#define PyFrame_GetLineNumber PyPyFrame_GetLineNumber
-PyAPI_FUNC(int) PyFrame_GetLineNumber(PyFrameObject *arg0);
-#define PyFrame_GetLocals PyPyFrame_GetLocals
-PyAPI_FUNC(struct _object *) PyFrame_GetLocals(PyFrameObject *arg0);
 #define PyFrame_New PyPyFrame_New
 PyAPI_FUNC(PyFrameObject *) PyFrame_New(PyThreadState *arg0, PyCodeObject *arg1, struct _object *arg2, struct _object *arg3);
 #define PyFrozenSet_Check PyPyFrozenSet_Check
@@ -386,18 +355,6 @@ PyAPI_FUNC(int) PyFunction_Check(void * arg0);
 PyAPI_FUNC(int) PyFunction_CheckExact(void * arg0);
 #define PyFunction_GetCode PyPyFunction_GetCode
 PyAPI_FUNC(struct _object *) PyFunction_GetCode(struct _object *arg0);
-#define PyFunction_GetGlobals PyPyFunction_GetGlobals
-PyAPI_FUNC(struct _object *) PyFunction_GetGlobals(struct _object *arg0);
-#define PyFunction_GetModule PyPyFunction_GetModule
-PyAPI_FUNC(struct _object *) PyFunction_GetModule(struct _object *arg0);
-#define PyGC_Collect PyPyGC_Collect
-PyAPI_FUNC(int) PyGC_Collect(void);
-#define PyGC_Disable PyPyGC_Disable
-PyAPI_FUNC(int) PyGC_Disable(void);
-#define PyGC_Enable PyPyGC_Enable
-PyAPI_FUNC(int) PyGC_Enable(void);
-#define PyGC_IsEnabled PyPyGC_IsEnabled
-PyAPI_FUNC(int) PyGC_IsEnabled(void);
 #define PyGILState_Check PyPyGILState_Check
 PyAPI_FUNC(int) PyGILState_Check(void);
 #define PyGILState_Ensure PyPyGILState_Ensure
@@ -428,6 +385,8 @@ PyAPI_FUNC(PyObject *) PyImport_ImportModuleLevelObject(PyObject * arg0, PyObjec
 PyAPI_FUNC(struct _object *) PyImport_ImportModuleNoBlock(const char *arg0);
 #define PyImport_ReloadModule PyPyImport_ReloadModule
 PyAPI_FUNC(struct _object *) PyImport_ReloadModule(struct _object *arg0);
+#define PyIndex_Check PyPyIndex_Check
+PyAPI_FUNC(int) PyIndex_Check(struct _object *arg0);
 #define PyInstanceMethod_Check PyPyInstanceMethod_Check
 PyAPI_FUNC(int) PyInstanceMethod_Check(struct _object *arg0);
 #define PyInstanceMethod_Function PyPyInstanceMethod_Function
@@ -446,8 +405,6 @@ PyAPI_FUNC(PyInterpreterState *) PyInterpreterState_Next(PyInterpreterState *arg
 PyAPI_FUNC(int) PyIter_Check(struct _object *arg0);
 #define PyIter_Next PyPyIter_Next
 PyAPI_FUNC(struct _object *) PyIter_Next(struct _object *arg0);
-#define PyIter_Send PyPyIter_Send
-PyAPI_FUNC(int) PyIter_Send(struct _object *arg0, struct _object *arg1, struct _object **arg2);
 #define PyList_Append PyPyList_Append
 PyAPI_FUNC(int) PyList_Append(struct _object *arg0, struct _object *arg1);
 #define PyList_AsTuple PyPyList_AsTuple
@@ -487,17 +444,17 @@ PyAPI_FUNC(Signed) PyLong_AsLongLong(struct _object *arg0);
 #define PyLong_AsLongLongAndOverflow PyPyLong_AsLongLongAndOverflow
 PyAPI_FUNC(Signed) PyLong_AsLongLongAndOverflow(struct _object *arg0, int *arg1);
 #define PyLong_AsSize_t PyPyLong_AsSize_t
-PyAPI_FUNC(size_t) PyLong_AsSize_t(struct _object *arg0);
+PyAPI_FUNC(Unsigned) PyLong_AsSize_t(struct _object *arg0);
 #define PyLong_AsSsize_t PyPyLong_AsSsize_t
 PyAPI_FUNC(Signed) PyLong_AsSsize_t(struct _object *arg0);
 #define PyLong_AsUnsignedLong PyPyLong_AsUnsignedLong
-PyAPI_FUNC(size_t) PyLong_AsUnsignedLong(struct _object *arg0);
+PyAPI_FUNC(Unsigned) PyLong_AsUnsignedLong(struct _object *arg0);
 #define PyLong_AsUnsignedLongLong PyPyLong_AsUnsignedLongLong
-PyAPI_FUNC(size_t) PyLong_AsUnsignedLongLong(struct _object *arg0);
+PyAPI_FUNC(Unsigned) PyLong_AsUnsignedLongLong(struct _object *arg0);
 #define PyLong_AsUnsignedLongLongMask PyPyLong_AsUnsignedLongLongMask
-PyAPI_FUNC(size_t) PyLong_AsUnsignedLongLongMask(struct _object *arg0);
+PyAPI_FUNC(Unsigned) PyLong_AsUnsignedLongLongMask(struct _object *arg0);
 #define PyLong_AsUnsignedLongMask PyPyLong_AsUnsignedLongMask
-PyAPI_FUNC(size_t) PyLong_AsUnsignedLongMask(struct _object *arg0);
+PyAPI_FUNC(Unsigned) PyLong_AsUnsignedLongMask(struct _object *arg0);
 #define PyLong_AsVoidPtr PyPyLong_AsVoidPtr
 PyAPI_FUNC(void *) PyLong_AsVoidPtr(struct _object *arg0);
 #define PyLong_FromDouble PyPyLong_FromDouble
@@ -507,7 +464,7 @@ PyAPI_FUNC(struct _object *) PyLong_FromLong(Signed arg0);
 #define PyLong_FromLongLong PyPyLong_FromLongLong
 PyAPI_FUNC(struct _object *) PyLong_FromLongLong(Signed arg0);
 #define PyLong_FromSize_t PyPyLong_FromSize_t
-PyAPI_FUNC(struct _object *) PyLong_FromSize_t(size_t arg0);
+PyAPI_FUNC(struct _object *) PyLong_FromSize_t(Unsigned arg0);
 #define PyLong_FromSsize_t PyPyLong_FromSsize_t
 PyAPI_FUNC(struct _object *) PyLong_FromSsize_t(Signed arg0);
 #define PyLong_FromString PyPyLong_FromString
@@ -517,9 +474,9 @@ PyAPI_FUNC(struct _object *) PyLong_FromUnicode(wchar_t *arg0, Signed arg1, int
 #define PyLong_FromUnicodeObject PyPyLong_FromUnicodeObject
 PyAPI_FUNC(struct _object *) PyLong_FromUnicodeObject(struct _object *arg0, int arg1);
 #define PyLong_FromUnsignedLong PyPyLong_FromUnsignedLong
-PyAPI_FUNC(struct _object *) PyLong_FromUnsignedLong(size_t arg0);
+PyAPI_FUNC(struct _object *) PyLong_FromUnsignedLong(Unsigned arg0);
 #define PyLong_FromUnsignedLongLong PyPyLong_FromUnsignedLongLong
-PyAPI_FUNC(struct _object *) PyLong_FromUnsignedLongLong(size_t arg0);
+PyAPI_FUNC(struct _object *) PyLong_FromUnsignedLongLong(Unsigned arg0);
 #define PyLong_FromVoidPtr PyPyLong_FromVoidPtr
 PyAPI_FUNC(struct _object *) PyLong_FromVoidPtr(void *arg0);
 #define PyMapping_Check PyPyMapping_Check
@@ -580,12 +537,8 @@ PyAPI_FUNC(struct _object *) PyModule_Create2(struct PyModuleDef *arg0, int arg1
 PyAPI_FUNC(int) PyModule_ExecDef(struct _object *arg0, struct PyModuleDef *arg1);
 #define PyModule_GetDict PyPyModule_GetDict
 PyAPI_FUNC(struct _object *) PyModule_GetDict(struct _object *arg0);
-#define PyModule_GetFilenameObject PyPyModule_GetFilenameObject
-PyAPI_FUNC(struct _object *) PyModule_GetFilenameObject(struct _object *arg0);
 #define PyModule_GetName PyPyModule_GetName
 PyAPI_FUNC(char *) PyModule_GetName(struct _object *arg0);
-#define PyModule_GetNameObject PyPyModule_GetNameObject
-PyAPI_FUNC(struct _object *) PyModule_GetNameObject(struct _object *arg0);
 #define PyModule_New PyPyModule_New
 PyAPI_FUNC(struct _object *) PyModule_New(const char *arg0);
 #define PyModule_NewObject PyPyModule_NewObject
@@ -598,6 +551,8 @@ PyAPI_FUNC(struct _object *) PyNumber_Add(struct _object *arg0, struct _object *
 PyAPI_FUNC(struct _object *) PyNumber_And(struct _object *arg0, struct _object *arg1);
 #define PyNumber_AsSsize_t PyPyNumber_AsSsize_t
 PyAPI_FUNC(Signed) PyNumber_AsSsize_t(struct _object *arg0, struct _object *arg1);
+#define PyNumber_Check PyPyNumber_Check
+PyAPI_FUNC(int) PyNumber_Check(struct _object *arg0);
 #define PyNumber_Divide PyPyNumber_Divide
 PyAPI_FUNC(struct _object *) PyNumber_Divide(struct _object *arg0, struct _object *arg1);
 #define PyNumber_Divmod PyPyNumber_Divmod
@@ -697,19 +652,19 @@ PyAPI_FUNC(struct _object *) PyObject_CallObject(struct _object *arg0, struct _o
 #define PyObject_CallOneArg PyPyObject_CallOneArg
 PyAPI_FUNC(struct _object *) PyObject_CallOneArg(struct _object *arg0, struct _object *arg1);
 #define PyObject_Calloc PyPyObject_Calloc
-PyAPI_FUNC(void *) PyObject_Calloc(size_t arg0, size_t arg1);
+PyAPI_FUNC(void *) PyObject_Calloc(Unsigned arg0, Unsigned arg1);
 #define PyObject_ClearWeakRefs PyPyObject_ClearWeakRefs
 PyAPI_FUNC(void) PyObject_ClearWeakRefs(struct _object *arg0);
+#define PyObject_DelAttr PyPyObject_DelAttr
+PyAPI_FUNC(int) PyObject_DelAttr(struct _object *arg0, struct _object *arg1);
+#define PyObject_DelAttrString PyPyObject_DelAttrString
+PyAPI_FUNC(int) PyObject_DelAttrString(struct _object *arg0, const char *arg1);
 #define PyObject_DelItem PyPyObject_DelItem
 PyAPI_FUNC(int) PyObject_DelItem(struct _object *arg0, struct _object *arg1);
 #define PyObject_Dir PyPyObject_Dir
 PyAPI_FUNC(struct _object *) PyObject_Dir(struct _object *arg0);
 #define PyObject_Format PyPyObject_Format
 PyAPI_FUNC(struct _object *) PyObject_Format(struct _object *arg0, struct _object *arg1);
-#define PyObject_GC_IsFinalized PyPyObject_GC_IsFinalized
-PyAPI_FUNC(int) PyObject_GC_IsFinalized(struct _object *arg0);
-#define PyObject_GC_IsTracked PyPyObject_GC_IsTracked
-PyAPI_FUNC(int) PyObject_GC_IsTracked(struct _object *arg0);
 #define PyObject_GenericGetAttr PyPyObject_GenericGetAttr
 PyAPI_FUNC(struct _object *) PyObject_GenericGetAttr(struct _object *arg0, struct _object *arg1);
 #define PyObject_GenericGetDict PyPyObject_GenericGetDict
@@ -743,13 +698,13 @@ PyAPI_FUNC(int) PyObject_IsTrue(struct _object *arg0);
 #define PyObject_LengthHint PyPyObject_LengthHint
 PyAPI_FUNC(Py_ssize_t) PyObject_LengthHint(PyObject * arg0, Py_ssize_t arg1);
 #define PyObject_Malloc PyPyObject_Malloc
-PyAPI_FUNC(void *) PyObject_Malloc(size_t arg0);
+PyAPI_FUNC(void *) PyObject_Malloc(Unsigned arg0);
 #define PyObject_Not PyPyObject_Not
 PyAPI_FUNC(int) PyObject_Not(struct _object *arg0);
 #define PyObject_Print PyPyObject_Print
 PyAPI_FUNC(int) PyObject_Print(struct _object *arg0, FILE *arg1, int arg2);
 #define PyObject_Realloc PyPyObject_Realloc
-PyAPI_FUNC(void *) PyObject_Realloc(void *arg0, size_t arg1);
+PyAPI_FUNC(void *) PyObject_Realloc(void *arg0, Unsigned arg1);
 #define PyObject_Repr PyPyObject_Repr
 PyAPI_FUNC(struct _object *) PyObject_Repr(struct _object *arg0);
 #define PyObject_RichCompare PyPyObject_RichCompare
@@ -884,22 +839,14 @@ PyAPI_FUNC(void) PyThreadState_Clear(PyThreadState *arg0);
 PyAPI_FUNC(void) PyThreadState_Delete(PyThreadState *arg0);
 #define PyThreadState_DeleteCurrent PyPyThreadState_DeleteCurrent
 PyAPI_FUNC(void) PyThreadState_DeleteCurrent(void);
-#define PyThreadState_EnterTracing PyPyThreadState_EnterTracing
-PyAPI_FUNC(void) PyThreadState_EnterTracing(PyThreadState *arg0);
 #define PyThreadState_Get PyPyThreadState_Get
 PyAPI_FUNC(PyThreadState *) PyThreadState_Get(void);
 #define PyThreadState_GetDict PyPyThreadState_GetDict
 PyAPI_FUNC(struct _object *) PyThreadState_GetDict(void);
-#define PyThreadState_GetFrame PyPyThreadState_GetFrame
-PyAPI_FUNC(PyFrameObject *) PyThreadState_GetFrame(PyThreadState *arg0);
-#define PyThreadState_GetID PyPyThreadState_GetID
-PyAPI_FUNC(size_t) PyThreadState_GetID(PyThreadState *arg0);
-#define PyThreadState_LeaveTracing PyPyThreadState_LeaveTracing
-PyAPI_FUNC(void) PyThreadState_LeaveTracing(PyThreadState *arg0);
 #define PyThreadState_New PyPyThreadState_New
 PyAPI_FUNC(PyThreadState *) PyThreadState_New(PyInterpreterState *arg0);
 #define PyThreadState_SetAsyncExc PyPyThreadState_SetAsyncExc
-PyAPI_FUNC(int) PyThreadState_SetAsyncExc(size_t arg0, struct _object *arg1);
+PyAPI_FUNC(int) PyThreadState_SetAsyncExc(Unsigned arg0, struct _object *arg1);
 #define PyThreadState_Swap PyPyThreadState_Swap
 PyAPI_FUNC(PyThreadState *) PyThreadState_Swap(PyThreadState *arg0);
 #define PyThread_exit_thread PyPyThread_exit_thread
@@ -926,8 +873,12 @@ PyAPI_FUNC(Signed) PyTuple_Size(struct _object *arg0);
 PyAPI_FUNC(PyObject *) PyType_FromModuleAndSpec(PyObject * arg0, PyType_Spec * arg1, PyObject * arg2);
 #define PyType_FromSpecWithBases PyPyType_FromSpecWithBases
 PyAPI_FUNC(PyObject *) PyType_FromSpecWithBases(PyType_Spec * arg0, PyObject * arg1);
+#define PyType_GenericNew PyPyType_GenericNew
+PyAPI_FUNC(struct _object *) PyType_GenericNew(struct _typeobject *arg0, struct _object *arg1, struct _object *arg2);
 #define PyType_GetSlot PyPyType_GetSlot
 PyAPI_FUNC(void *) PyType_GetSlot(struct _typeobject *arg0, int arg1);
+#define PyType_IsSubtype PyPyType_IsSubtype
+PyAPI_FUNC(int) PyType_IsSubtype(struct _typeobject *arg0, struct _typeobject *arg1);
 #define PyType_Modified PyPyType_Modified
 PyAPI_FUNC(void) PyType_Modified(struct _typeobject *arg0);
 #define PyType_Ready PyPyType_Ready
@@ -956,6 +907,8 @@ PyAPI_FUNC(char *) PyUnicode_AsUTF8(PyObject * arg0);
 PyAPI_FUNC(char *) PyUnicode_AsUTF8AndSize(PyObject * arg0, Py_ssize_t * arg1);
 #define PyUnicode_AsUTF8String PyPyUnicode_AsUTF8String
 PyAPI_FUNC(struct _object *) PyUnicode_AsUTF8String(struct _object *arg0);
+#define PyUnicode_AsUnicode PyPyUnicode_AsUnicode
+PyAPI_FUNC(Py_UNICODE *) PyUnicode_AsUnicode(PyObject * arg0);
 #define PyUnicode_AsUnicodeAndSize PyPyUnicode_AsUnicodeAndSize
 PyAPI_FUNC(Py_UNICODE *) PyUnicode_AsUnicodeAndSize(PyObject * arg0, Py_ssize_t * arg1);
 #define PyUnicode_AsUnicodeEscapeString PyPyUnicode_AsUnicodeEscapeString
@@ -1096,8 +1049,6 @@ PyAPI_FUNC(int) Py_GetRecursionLimit(void);
 PyAPI_FUNC(char *) Py_GetVersion(void);
 #define Py_IncRef PyPy_IncRef
 PyAPI_FUNC(void) Py_IncRef(struct _object *arg0);
-#define Py_Is PyPy_Is
-PyAPI_FUNC(int) Py_Is(struct _object *arg0, struct _object *arg1);
 #define Py_IsInitialized PyPy_IsInitialized
 PyAPI_FUNC(int) Py_IsInitialized(void);
 #define Py_LeaveRecursiveCall PyPy_LeaveRecursiveCall
@@ -1112,6 +1063,38 @@ PyAPI_FUNC(void) Py_ReprLeave(struct _object *arg0);
 PyAPI_FUNC(void) Py_SetRecursionLimit(int arg0);
 #define Py_UNICODE_COPY PyPy_UNICODE_COPY
 PyAPI_FUNC(void) Py_UNICODE_COPY(wchar_t *arg0, wchar_t *arg1, Signed arg2);
+#define Py_UNICODE_ISALNUM PyPy_UNICODE_ISALNUM
+PyAPI_FUNC(int) Py_UNICODE_ISALNUM(wchar_t arg0);
+#define Py_UNICODE_ISALPHA PyPy_UNICODE_ISALPHA
+PyAPI_FUNC(int) Py_UNICODE_ISALPHA(wchar_t arg0);
+#define Py_UNICODE_ISDECIMAL PyPy_UNICODE_ISDECIMAL
+PyAPI_FUNC(int) Py_UNICODE_ISDECIMAL(wchar_t arg0);
+#define Py_UNICODE_ISDIGIT PyPy_UNICODE_ISDIGIT
+PyAPI_FUNC(int) Py_UNICODE_ISDIGIT(wchar_t arg0);
+#define Py_UNICODE_ISLINEBREAK PyPy_UNICODE_ISLINEBREAK
+PyAPI_FUNC(int) Py_UNICODE_ISLINEBREAK(wchar_t arg0);
+#define Py_UNICODE_ISLOWER PyPy_UNICODE_ISLOWER
+PyAPI_FUNC(int) Py_UNICODE_ISLOWER(wchar_t arg0);
+#define Py_UNICODE_ISNUMERIC PyPy_UNICODE_ISNUMERIC
+PyAPI_FUNC(int) Py_UNICODE_ISNUMERIC(wchar_t arg0);
+#define Py_UNICODE_ISSPACE PyPy_UNICODE_ISSPACE
+PyAPI_FUNC(int) Py_UNICODE_ISSPACE(wchar_t arg0);
+#define Py_UNICODE_ISTITLE PyPy_UNICODE_ISTITLE
+PyAPI_FUNC(int) Py_UNICODE_ISTITLE(wchar_t arg0);
+#define Py_UNICODE_ISUPPER PyPy_UNICODE_ISUPPER
+PyAPI_FUNC(int) Py_UNICODE_ISUPPER(wchar_t arg0);
+#define Py_UNICODE_TODECIMAL PyPy_UNICODE_TODECIMAL
+PyAPI_FUNC(int) Py_UNICODE_TODECIMAL(wchar_t arg0);
+#define Py_UNICODE_TODIGIT PyPy_UNICODE_TODIGIT
+PyAPI_FUNC(int) Py_UNICODE_TODIGIT(wchar_t arg0);
+#define Py_UNICODE_TOLOWER PyPy_UNICODE_TOLOWER
+PyAPI_FUNC(wchar_t) Py_UNICODE_TOLOWER(wchar_t arg0);
+#define Py_UNICODE_TONUMERIC PyPy_UNICODE_TONUMERIC
+PyAPI_FUNC(double) Py_UNICODE_TONUMERIC(wchar_t arg0);
+#define Py_UNICODE_TOTITLE PyPy_UNICODE_TOTITLE
+PyAPI_FUNC(wchar_t) Py_UNICODE_TOTITLE(wchar_t arg0);
+#define Py_UNICODE_TOUPPER PyPy_UNICODE_TOUPPER
+PyAPI_FUNC(wchar_t) Py_UNICODE_TOUPPER(wchar_t arg0);
 #define _PyBytes_Eq _PyPyBytes_Eq
 PyAPI_FUNC(int) _PyBytes_Eq(struct _object *arg0, struct _object *arg1);
 #define _PyBytes_Join _PyPyBytes_Join
@@ -1142,12 +1125,12 @@ PyAPI_FUNC(struct _object *) _PyDict_GetItemStringWithError(struct _object *arg0
 PyAPI_FUNC(int) _PyDict_HasOnlyStringKeys(struct _object *arg0);
 #define _PyErr_WriteUnraisableMsg _PyPyErr_WriteUnraisableMsg
 PyAPI_FUNC(void) _PyErr_WriteUnraisableMsg(const char *arg0, struct _object *arg1);
-#define _PyEval_GetAsyncGenFinalizer _PyPyEval_GetAsyncGenFinalizer
-PyAPI_FUNC(struct _object *) _PyEval_GetAsyncGenFinalizer(void);
-#define _PyEval_GetAsyncGenFirstiter _PyPyEval_GetAsyncGenFirstiter
-PyAPI_FUNC(struct _object *) _PyEval_GetAsyncGenFirstiter(void);
 #define _PyEval_SliceIndex _PyPyEval_SliceIndex
 PyAPI_FUNC(int) _PyEval_SliceIndex(struct _object *arg0, Signed *arg1);
+#define _PyFloat_Unpack4 _PyPyFloat_Unpack4
+PyAPI_FUNC(double) _PyFloat_Unpack4(const unsigned char *arg0, int arg1);
+#define _PyFloat_Unpack8 _PyPyFloat_Unpack8
+PyAPI_FUNC(double) _PyFloat_Unpack8(const unsigned char *arg0, int arg1);
 #define _PyImport_AcquireLock _PyPyImport_AcquireLock
 PyAPI_FUNC(void) _PyImport_AcquireLock(void);
 #define _PyImport_ReleaseLock _PyPyImport_ReleaseLock
@@ -1155,13 +1138,11 @@ PyAPI_FUNC(int) _PyImport_ReleaseLock(void);
 #define _PyList_Extend _PyPyList_Extend
 PyAPI_FUNC(struct _object *) _PyList_Extend(struct _object *arg0, struct _object *arg1);
 #define _PyLong_AsByteArrayO _PyPyLong_AsByteArrayO
-PyAPI_FUNC(int) _PyLong_AsByteArrayO(struct _object *arg0, unsigned char *arg1, size_t arg2, int arg3, int arg4);
-#define _PyLong_AsInt _PyPyLong_AsInt
-PyAPI_FUNC(int) _PyLong_AsInt(struct _object *arg0);
+PyAPI_FUNC(int) _PyLong_AsByteArrayO(struct _object *arg0, unsigned char *arg1, Unsigned arg2, int arg3, int arg4);
 #define _PyLong_FromByteArray _PyPyLong_FromByteArray
-PyAPI_FUNC(struct _object *) _PyLong_FromByteArray(const unsigned char *arg0, size_t arg1, int arg2, int arg3);
+PyAPI_FUNC(struct _object *) _PyLong_FromByteArray(const unsigned char *arg0, Unsigned arg1, int arg2, int arg3);
 #define _PyLong_NumBits _PyPyLong_NumBits
-PyAPI_FUNC(size_t) _PyLong_NumBits(struct _object *arg0);
+PyAPI_FUNC(Unsigned) _PyLong_NumBits(struct _object *arg0);
 #define _PyLong_Sign _PyPyLong_Sign
 PyAPI_FUNC(int) _PyLong_Sign(struct _object *arg0);
 #define _PyNamespace_New _PyPyNamespace_New
@@ -1180,8 +1161,6 @@ extern void * _PyPy_Malloc(Signed arg0);
 PyAPI_FUNC(int) _PySet_Next(struct _object *arg0, Signed *arg1, struct _object **arg2);
 #define _PySet_NextEntry _PyPySet_NextEntry
 PyAPI_FUNC(int) _PySet_NextEntry(struct _object *arg0, Signed *arg1, struct _object **arg2, Signed *arg3);
-#define _PyThreadState_GetDict _PyPyThreadState_GetDict
-PyAPI_FUNC(struct _object *) _PyThreadState_GetDict(PyThreadState *arg0);
 #define _PyThreadState_UncheckedGet _PyPyThreadState_UncheckedGet
 PyAPI_FUNC(PyThreadState *) _PyThreadState_UncheckedGet(void);
 #define _PyTimeZone_FromTimeZone _PyPyTimeZone_FromTimeZone
@@ -1198,36 +1177,10 @@ PyAPI_FUNC(struct _object *) _PyType_Lookup(struct _typeobject *arg0, struct _ob
 PyAPI_FUNC(int) _PyUnicode_EQ(struct _object *arg0, struct _object *arg1);
 #define _PyUnicode_EqualToASCIIString _PyPyUnicode_EqualToASCIIString
 PyAPI_FUNC(int) _PyUnicode_EqualToASCIIString(struct _object *arg0, const char *arg1);
-#define _PyUnicode_IsAlpha _PyPyUnicode_IsAlpha
-PyAPI_FUNC(int) _PyUnicode_IsAlpha(unsigned int arg0);
-#define _PyUnicode_IsDecimalDigit _PyPyUnicode_IsDecimalDigit
-PyAPI_FUNC(int) _PyUnicode_IsDecimalDigit(unsigned int arg0);
-#define _PyUnicode_IsDigit _PyPyUnicode_IsDigit
-PyAPI_FUNC(int) _PyUnicode_IsDigit(unsigned int arg0);
-#define _PyUnicode_IsLowercase _PyPyUnicode_IsLowercase
-PyAPI_FUNC(int) _PyUnicode_IsLowercase(unsigned int arg0);
-#define _PyUnicode_IsNumeric _PyPyUnicode_IsNumeric
-PyAPI_FUNC(int) _PyUnicode_IsNumeric(unsigned int arg0);
-#define _PyUnicode_IsPrintable _PyPyUnicode_IsPrintable
-PyAPI_FUNC(int) _PyUnicode_IsPrintable(unsigned int arg0);
-#define _PyUnicode_IsTitlecase _PyPyUnicode_IsTitlecase
-PyAPI_FUNC(int) _PyUnicode_IsTitlecase(unsigned int arg0);
-#define _PyUnicode_IsUppercase _PyPyUnicode_IsUppercase
-PyAPI_FUNC(int) _PyUnicode_IsUppercase(unsigned int arg0);
 #define _PyUnicode_Ready _PyPyUnicode_Ready
 PyAPI_FUNC(int) _PyUnicode_Ready(PyObject * arg0);
-#define _PyUnicode_ToDecimalDigit _PyPyUnicode_ToDecimalDigit
-PyAPI_FUNC(int) _PyUnicode_ToDecimalDigit(unsigned int arg0);
-#define _PyUnicode_ToDigit _PyPyUnicode_ToDigit
-PyAPI_FUNC(int) _PyUnicode_ToDigit(unsigned int arg0);
-#define _PyUnicode_ToLowercase _PyPyUnicode_ToLowercase
-PyAPI_FUNC(unsigned int) _PyUnicode_ToLowercase(unsigned int arg0);
-#define _PyUnicode_ToTitlecase _PyPyUnicode_ToTitlecase
-PyAPI_FUNC(unsigned int) _PyUnicode_ToTitlecase(unsigned int arg0);
-#define _PyUnicode_ToUppercase _PyPyUnicode_ToUppercase
-PyAPI_FUNC(unsigned int) _PyUnicode_ToUppercase(unsigned int arg0);
 #define _Py_HashDouble _PyPy_HashDouble
-PyAPI_FUNC(Signed) _Py_HashDouble(struct _object *arg0, double arg1);
+PyAPI_FUNC(Signed) _Py_HashDouble(double arg0);
 #define _Py_HashPointer _PyPy_HashPointer
 PyAPI_FUNC(Signed) _Py_HashPointer(void *arg0);
 #define _Py_IsFinalizing _PyPy_IsFinalizing
@@ -1248,8 +1201,6 @@ PyAPI_DATA(PyObject) _Py_NotImplementedStruct;
 PyAPI_DATA(PyObject) _Py_EllipsisObject;
 #define PyDateTimeAPI PyPyDateTimeAPI
 PyAPI_DATA(PyDateTime_CAPI*) PyDateTimeAPI;
-#define Py_GenericAliasType PyPy_GenericAliasType
-PyAPI_DATA(PyTypeObject) Py_GenericAliasType;
 #define PyExc_ArithmeticError PyPyExc_ArithmeticError
 PyAPI_DATA(PyObject*) PyExc_ArithmeticError;
 #define PyExc_AssertionError PyPyExc_AssertionError
@@ -1258,8 +1209,6 @@ PyAPI_DATA(PyObject*) PyExc_AssertionError;
 PyAPI_DATA(PyObject*) PyExc_AttributeError;
 #define PyExc_BaseException PyPyExc_BaseException
 PyAPI_DATA(PyObject*) PyExc_BaseException;
-#define PyExc_BaseExceptionGroup PyPyExc_BaseExceptionGroup
-PyAPI_DATA(PyObject*) PyExc_BaseExceptionGroup;
 #define PyExc_BlockingIOError PyPyExc_BlockingIOError
 PyAPI_DATA(PyObject*) PyExc_BlockingIOError;
 #define PyExc_BrokenPipeError PyPyExc_BrokenPipeError
@@ -1282,12 +1231,8 @@ PyAPI_DATA(PyObject*) PyExc_ConnectionResetError;
 PyAPI_DATA(PyObject*) PyExc_DeprecationWarning;
 #define PyExc_EOFError PyPyExc_EOFError
 PyAPI_DATA(PyObject*) PyExc_EOFError;
-#define PyExc_EncodingWarning PyPyExc_EncodingWarning
-PyAPI_DATA(PyObject*) PyExc_EncodingWarning;
 #define PyExc_Exception PyPyExc_Exception
 PyAPI_DATA(PyObject*) PyExc_Exception;
-#define PyExc_ExceptionGroup PyPyExc_ExceptionGroup
-PyAPI_DATA(PyObject*) PyExc_ExceptionGroup;
 #define PyExc_FileExistsError PyPyExc_FileExistsError
 PyAPI_DATA(PyObject*) PyExc_FileExistsError;
 #define PyExc_FileNotFoundError PyPyExc_FileNotFoundError
@@ -1384,6 +1329,8 @@ PyAPI_DATA(PyObject*) PyExc_ValueError;
 PyAPI_DATA(PyObject*) PyExc_Warning;
 #define PyExc_ZeroDivisionError PyPyExc_ZeroDivisionError
 PyAPI_DATA(PyObject*) PyExc_ZeroDivisionError;
+#define PyType_Type PyPyType_Type
+PyAPI_DATA(PyTypeObject) PyType_Type;
 #define PyBytes_Type PyPyBytes_Type
 PyAPI_DATA(PyTypeObject) PyBytes_Type;
 #define PyUnicode_Type PyPyUnicode_Type
@@ -1460,10 +1407,6 @@ PyAPI_DATA(PyTypeObject) PyFunction_Type;
 PyAPI_DATA(PyTypeObject) PyMethod_Type;
 #define PyTraceBack_Type PyPyTraceBack_Type
 PyAPI_DATA(PyTypeObject) PyTraceBack_Type;
-#define PyCapsule_Type PyPyCapsule_Type
-PyAPI_DATA(PyTypeObject) PyCapsule_Type;
-#define PyFrame_Type PyPyFrame_Type
-PyAPI_DATA(PyTypeObject) PyFrame_Type;
 
 #undef Signed    /* xxx temporary fix */
 #undef Unsigned  /* xxx temporary fix */
